@@ -84,6 +84,15 @@ int fluid_handle_router_chan(void *data, int ac, char **av, fluid_ostream_t out)
 int fluid_handle_router_par1(void *data, int ac, char **av, fluid_ostream_t out);
 int fluid_handle_router_par2(void *data, int ac, char **av, fluid_ostream_t out);
 
+int fluid_handle_player_start(void *data, int ac, char **av, fluid_ostream_t out);
+int fluid_handle_player_stop(void *data, int ac, char **av, fluid_ostream_t out);
+int fluid_handle_player_continue(void *data, int ac, char **av, fluid_ostream_t out);
+int fluid_handle_player_next_song(void *data, int ac, char **av, fluid_ostream_t out);
+int fluid_handle_player_seek(void *data, int ac, char **av, fluid_ostream_t out);
+int fluid_handle_player_loop(void *data, int ac, char **av, fluid_ostream_t out);
+int fluid_handle_player_tempo_bpm(void *data, int ac, char **av, fluid_ostream_t out);
+int fluid_handle_player_tempo_int(void *data, int ac, char **av, fluid_ostream_t out);
+
 #if WITH_PROFILING
 int fluid_handle_profile(void *data, int ac, char **av, fluid_ostream_t out);
 int fluid_handle_prof_set_notes(void *data, int ac, char **av, fluid_ostream_t out);
