@@ -31,7 +31,7 @@ fluid_real_t fluid_tc2sec(fluid_real_t tc);
 fluid_real_t fluid_tc2sec_delay(fluid_real_t tc);
 fluid_real_t fluid_tc2sec_attack(fluid_real_t tc);
 fluid_real_t fluid_tc2sec_release(fluid_real_t tc);
-fluid_real_t fluid_act2hz(fluid_real_t c);
+double fluid_act2hz(double c);
 fluid_real_t fluid_pan(fluid_real_t c, int left);
 fluid_real_t fluid_balance(fluid_real_t balance, int left);
 fluid_real_t fluid_concave(fluid_real_t val);
