@@ -129,7 +129,18 @@ typedef gintptr  intptr_t;
 
 #endif
 
-#if defined(WIN32) &&  HAVE_WINDOWS_H
+/*
+ * CYGWIN has its own version of <windows.h>, which can be
+ * safely included together with POSIX includes.
+ * Thanks to this, CYGWIN can also run audio output and MIDI
+ * input drivers from traditional interfaces of Windows.
+ */
+#if defined(__CYGWIN__) && HAVE_WINDOWS_H
+#include <windows.h>
+#include <wchar.h>
+#endif
+
+#if defined(_WIN32) && HAVE_WINDOWS_H
 #include <winsock2.h>
 #include <ws2tcpip.h>	/* Provides also socklen_t */
 
@@ -167,7 +178,7 @@ typedef gintptr  intptr_t;
  */
 #define fluid_gerror_message(err)  ((err) ? err->message : "No error details")
 
-#ifdef WIN32
+#if defined(_WIN32) || defined(__CYGWIN__)
 char* fluid_get_windows_error(void);
 #endif
 
@@ -474,7 +485,7 @@ typedef GModule fluid_module_t;
 int fluid_istream_readline(fluid_istream_t in, fluid_ostream_t out, char *prompt, char *buf, int len);
 int fluid_ostream_printf(fluid_ostream_t out, const char *format, ...);
 
-#if defined(WIN32)
+#if defined(_WIN32)
 typedef SOCKET fluid_socket_t;
 #else
 typedef int fluid_socket_t;
@@ -498,7 +509,7 @@ fluid_ostream_t fluid_socket_get_ostream(fluid_socket_t sock);
     /* GStatBuf has not been introduced yet, manually typedef to what they had at that time:
      * https://github.com/GNOME/glib/blob/e7763678b56e3be073cc55d707a6e92fc2055ee0/glib/gstdio.h#L98-L115
      */
-    #if defined(WIN32) || HAVE_WINDOWS_H // somehow reliably mock G_OS_WIN32??
+    #if defined(_WIN32) || HAVE_WINDOWS_H // somehow reliably mock G_OS_WIN32??
         // Any effort from our side to reliably mock GStatBuf on Windows is in vain. E.g. glib-2.16 is broken as it uses struct stat rather than struct _stat32 on Win x86.
         // Disable it (the user has been warned by cmake).
         #undef fluid_stat
@@ -575,7 +586,7 @@ int fluid_profile_is_cancel_req(void);
  1) Adds #define FLUID_PROFILE_CANCEL
  2) Adds the necessary code inside fluid_profile_is_cancel() see fluid_sys.c
 */
-#if defined(WIN32)      /* Profile cancellation is supported for Windows */
+#if defined(_WIN32)      /* Profile cancellation is supported for Windows */
 #define FLUID_PROFILE_CANCEL
 
 #elif defined(__OS2__)  /* OS/2 specific stuff */
